==> haskell-wl-pprint-extras-3.5.0.5-433-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-L6Ka8McCcg36eCH6G6eTD
key:                  wl-pprint-extras-3.5.0.5-L6Ka8McCcg36eCH6G6eTD
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  a1d3a64bbf692989023d5e98006a5c07
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-L6Ka8McCcg36eCH6G6eTD
depends:
    base-4.16.4.0 containers-0.6.5.1
    semigroupoids-5.3.7-Aol4v1yb5Zg1lc2q2bwPkl text-1.2.5.0
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-434-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-AUA4GaDxlslBsK63v6yUIi
key:                  wl-pprint-extras-3.5.0.5-AUA4GaDxlslBsK63v6yUIi
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  548815868399db462af4a5c24ead4be1
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-AUA4GaDxlslBsK63v6yUIi
depends:
    base-4.16.4.0 containers-0.6.5.1
    semigroupoids-5.3.7-CmdCtkiMB79IiDSsUdUQis text-1.2.5.0
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
